@@ -2,8 +2,6 @@ from .worker import Worker
 from .queue import Queue
 from .job import Job
 from .script import main
-from ruamel.yaml import YAML
-from argparse import Action
 
 if __name__ == "__main__":
   main()
\ No newline at end of file
