@@ -53,8 +53,9 @@ try:
         if not stdfile is None:
           stdfile.close()
         err = "Function " + str(callback) + " not found!"
-        data = json.dumps({"error": err}, default=json_util.default)
-        sys.stdout.write(data)
+        raise Exception(err)
+        #data = json.dumps({"error": {message: err}}, default=json_util.default)
+        #sys.stdout.write(data)
 
 except Exception as ex:
   sys.stdout = temp_stdout
@@ -62,7 +63,7 @@ except Exception as ex:
   if not stdfile is None:
     stdfile.close()
   errtrace = traceback.format_exc()
-  err = "Error " + str(exc)
+  err = "Error " + str(ex)
   data = json.dumps({"error": {"trace": str(errtrace), "message": err}}, default=json_util.default)
   sys.stdout.write(data)
 
